<?php
/**
 * Module Name: Photon
 * Module Description: Accelerate your site by loading images from the WordPress.com CDN.
 * Sort Order: 25
 * First Introduced: 2.0
 * Requires Connection: Yes
 * Auto Activate: No
 * Module Tags: Photos and Videos, Appearance
 */

Jetpack_Photon::instance();