<?php

/**
 * Module Name: Widget Visibility
 * Module Description: Specify which widgets appear on which pages of your site.
 * First Introduced: 2.4
 * Requires Connection: No
 * Auto Activate: Yes
 * Sort Order: 17
 * Module Tags: Appearance
 */

include dirname( __FILE__ ) . "/widget-visibility/widget-conditions.php";
