// Imported styles
@import "scss/_variables"; // Global variables including colors and font sets
@import "scss/_mixins"; // Contains all the variables, mixins and MORE!
// @import "scss/_normalize"; // Normalize.css + a goody or two
@import "scss/_base"; // Contains base element styling

// Begin partials
@import "scss/partials/_animations"; // All the keyframe animations
@import "scss/partials/_buttons"; // Fun button styles
@import "scss/icons/_automatticons"; // A list of the icons available
@import "scss/icons/_jetpack"; // Jetpack logo and icons
@import "scss/partials/_nav-horizontal"; // Horizontal menus
// End partials

@import "scss/_main"; // Main styles go here
@import "scss/_page-modules"; // Modules page styles
@import "scss/_media-queries"; // Contains media query styles. Break up into _tablet, _phone, etc if necessary.
@import "scss/_helper"; // Some fun helper classes
@import "scss/_ie"; // IE specific styling
