// ==========================================================================
// First Post
// ==========================================================================

.first-post {
	margin: 0 auto;
	max-width: 700px;
}

#title-prompt-text,
#mce_48-body,
.wp-editor-tabs {
	display: none;
}

#title {
	margin-bottom: 20px;
	border-radius: 3px;
	background: #fff;
	border: 1px solid #ddd;
	color:#222;
	font-size: 28px;
	font-weight: 700;
	box-shadow: inset 0 1px 1px rgba(0,0,0,0.1);

	@include breakpoint(tablet) {
		font-size: 18px;
	}
}

#mce_41-body,
#postdivrich {
	border: 1px solid #ddd;
	border-radius: 3px;
}

#mce_41 {
	background: #f9f9f9;
}

.skip-post {
	display:inline-block;
	margin-top:13px;
	margin-left:10px;
}

.mceContentBody {
	margin: 0 auto;
}
