#menu-posts-feedback .wp-menu-image img {
	display: none;
}

#adminmenu .menu-icon-feedback div.wp-menu-image {
	background: none !important;
}

#adminmenu .menu-icon-feedback div.wp-menu-image:before {
	content: '\f175';
	margin-left: -1px;
}

.jetpack-contact-form-icon:before {
	content: '\f175';
	color: #888;
	vertical-align: text-bottom;
	font: normal 18px/1 'dashicons';
	speak: none;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

.pre-mp6 #adminmenu .menu-icon-feedback:hover div.wp-menu-image,
.pre-mp6 #adminmenu .menu-icon-feedback.wp-has-current-submenu div.wp-menu-image,
.pre-mp6 #adminmenu .menu-icon-feedback.current div.wp-menu-image {
	background: url(../images/grunion-menu-hover.png) no-repeat 7px 7px !important;
	background-size: 15px 16px !important;
}

.pre-mp6 #adminmenu .menu-icon-feedback div.wp-menu-image {
	background: url(../images/grunion-menu.png) no-repeat 7px 7px !important;
	background-size: 15px 16px !important;
}

.pre-mp6 #adminmenu .menu-icon-feedback div.wp-menu-image:before {
	display: none;
}

.pre-mp6 .jetpack-contact-form-icon {
	background: url(../images/grunion-form.png) no-repeat;
	width: 16px;
	height: 16px;
	display: inline-block;
	vertical-align: middle;
	background-size: 13px 12px !important;
}

.pre-mp6 .jetpack-contact-form-icon:before {
	display: none;
}

@media only screen and (-moz-min-device-pixel-ratio: 1.5),
	only screen and (-o-min-device-pixel-ratio: 3/2),
	only screen and (-webkit-min-device-pixel-ratio: 1.5),
	only screen and (min-device-pixel-ratio: 1.5) {

	.pre-mp6 #adminmenu .menu-icon-feedback:hover div.wp-menu-image,
	.pre-mp6 #adminmenu .menu-icon-feedback.wp-has-current-submenu div.wp-menu-image,
	.pre-mp6 #adminmenu .menu-icon-feedback.current div.wp-menu-image {
		background-image: url(../images/grunion-menu-hover-2x.png);
	}

	.pre-mp6 #adminmenu .menu-icon-feedback div.wp-menu-image {
		background-image: url(../images/grunion-menu-2x.png);
	}

	.pre-mp6 .jetpack-contact-form-icon {
		background-image: url(../images/grunion-form-2x.png);
		vertical-align: bottom;
	}

}

