<?php
/**
 * Module Name: Contact Form
 * Module Description: Insert a contact form anywhere on your site.
 * Sort Order: 15
 * First Introduced: 1.3
 * Requires Connection: No
 * Auto Activate: Yes
 * Module Tags: Other
 */

include dirname( __FILE__ ) . '/contact-form/grunion-contact-form.php';
