/*! normalize.css v3.0.0 | MIT License | git.io/normalize */
@import url(//fonts.googleapis.com/css?family=Open+Sans:400italic,700italic,400,600,700);
html {
  font-family: sans-serif;
  -ms-text-size-adjust: 100%;
  -webkit-text-size-adjust: 100%;
}

body {
  margin: 0;
}

*,
*:before,
*:after {
  /* apply a natural box layout model to all elements; see http://www.paulirish.com/2012/box-sizing-border-box-ftw/ */
  -webkit-box-sizing: border-box;
  /* Not needed for modern webkit but still used by Blackberry Browser 7.0; see http://caniuse.com/#search=box-sizing */
  -moz-box-sizing: border-box;
  /* Still needed for Firefox 28; see http://caniuse.com/#search=box-sizing */
  box-sizing: border-box;
}

article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
nav,
section,
summary {
  display: block;
}

audio,
canvas,
progress,
video {
  display: inline-block;
  vertical-align: baseline;
}

audio:not([controls]) {
  display: none;
  height: 0;
}

[hidden],
template {
  display: none;
}

a {
  background: transparent;
}

a:active,
a:hover {
  outline: 0;
}

abbr[title] {
  border-bottom: 1px dotted;
}

b,
strong {
  font-weight: bold;
}

dfn {
  font-style: italic;
}

h1 {
  font-size: 2em;
  margin: 0.67em 0;
}

mark {
  background: #ff0;
  color: #000;
}

small {
  font-size: 80%;
}

sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
}

sup {
  top: -0.5em;
}

sub {
  bottom: -0.25em;
}

img {
  border: 0;
}

svg:not(:root) {
  overflow: hidden;
}

figure {
  margin: 1em 40px;
}

hr {
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  height: 0;
}

pre {
  overflow: auto;
}

code,
kbd,
pre,
samp {
  font-family: monospace, monospace;
  font-size: 1em;
}

button,
input,
optgroup,
select,
textarea {
  color: inherit;
  font: inherit;
  margin: 0;
}

button {
  overflow: visible;
}

button,
select {
  text-transform: none;
}

button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
  -webkit-appearance: button;
  cursor: pointer;
}

button[disabled],
html input[disabled] {
  cursor: default;
}

button::-moz-focus-inner,
input::-moz-focus-inner {
  border: 0;
  padding: 0;
}

input {
  line-height: normal;
}

input[type="checkbox"],
input[type="radio"] {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  padding: 0;
}

input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
  height: auto;
}

input[type="search"] {
  -webkit-appearance: textfield;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}

input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none;
}

fieldset {
  border: 1px solid #c0c0c0;
  margin: 0 2px;
  padding: 0.35em 0.625em 0.75em;
}

legend {
  border: 0;
  padding: 0;
}

textarea {
  overflow: auto;
}

optgroup {
  font-weight: bold;
}

table {
  border-collapse: collapse;
  border-spacing: 0;
}

td,
th {
  padding: 0;
}

body,
button,
input,
select,
textarea {
  color: #222222;
  font-family: "Open Sans", Helvetica, Arial, sans-serif;
  font-size: 16px;
  font-weight: 400;
  line-height: 1.4;
}

h1,
h2,
h3,
h4,
h5,
h6 {
  clear: both;
  color: #222;
  font-weight: 700;
}

p {
  margin-bottom: 1.5em;
}

b,
strong {
  font-weight: 700;
}

dfn,
cite,
em,
i {
  font-style: italic;
}

blockquote {
  margin: 1em 1.5em;
  font-size: 1.5625em;
  font-style: italic;
}

address {
  margin: 0 0 1.5em;
}

pre {
  background: #eeeeee;
  font-family: "Courier 10 Pitch", Courier, monospace;
  font-size: 15px;
  font-size: 1.5rem;
  line-height: 1.6;
  margin-bottom: 1.6em;
  max-width: 100%;
  overflow: auto;
  padding: 1.6em;
}

code,
kbd,
tt,
var {
  font: 15px Monaco, Consolas, "Andale Mono", "DejaVu Sans Mono", monospace;
}

abbr,
acronym {
  border-bottom: 1px dotted #666;
  cursor: help;
}

mark,
ins {
  background: #fff9c0;
  text-decoration: none;
}

sup,
sub {
  font-size: 75%;
  height: 0;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
}

sup {
  bottom: 1ex;
}

sub {
  top: .5ex;
}

small {
  font-size: 75%;
}

big {
  font-size: 125%;
}

/**

	Genericons Helper CSS

*/
/**
 * The font was graciously generated by Font Squirrel (http://www.fontsquirrel.com). We love those guys.
 */
@font-face {
  font-family: 'Genericons';
  src: url("../font/genericons-regular-webfont.eot");
}
@font-face {
  font-family: 'Genericons';
  src: url(data:application/font-woff;charset=utf-8;base64, ) format("woff"), url("../font/genericons-regular-webfont.ttf") format("truetype"), url("../font/genericons-regular-webfont.svg#genericonsregular") format("svg");
  font-weight: normal;
  font-style: normal;
}
/**
 * All Genericons
 */
.genericon {
  display: inline-block;
  width: 16px;
  height: 16px;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-size: 16px;
  line-height: 1;
  font-family: 'Genericons';
  text-decoration: inherit;
  font-weight: normal;
  font-style: normal;
  vertical-align: top;
}

/**
 * IE7 and IE6 hacks
 */
.genericon {
  *overflow: auto;
  *zoom: 1;
  *display: inline;
}

/**
 * Individual icons
 */
/* Post formats */
.genericon-standard:before {
  content: '\f100';
}

.genericon-aside:before {
  content: '\f101';
}

.genericon-image:before {
  content: '\f102';
}

.genericon-gallery:before {
  content: '\f103';
}

.genericon-video:before {
  content: '\f104';
}

.genericon-status:before {
  content: '\f105';
}

.genericon-quote:before {
  content: '\f106';
}

.genericon-link:before {
  content: '\f107';
}

.genericon-chat:before {
  content: '\f108';
}

.genericon-audio:before {
  content: '\f109';
}

/* Social icons */
.genericon-github:before {
  content: '\f200';
}

.genericon-dribbble:before {
  content: '\f201';
}

.genericon-twitter:before {
  content: '\f202';
}

.genericon-facebook:before {
  content: '\f203';
}

.genericon-facebook-alt:before {
  content: '\f204';
}

.genericon-wordpress:before {
  content: '\f205';
}

.genericon-googleplus:before {
  content: '\f206';
}

.genericon-linkedin:before {
  content: '\f207';
}

.genericon-linkedin-alt:before {
  content: '\f208';
}

.genericon-pinterest:before {
  content: '\f209';
}

.genericon-pinterest-alt:before {
  content: '\f210';
}

.genericon-flickr:before {
  content: '\f211';
}

.genericon-vimeo:before {
  content: '\f212';
}

.genericon-youtube:before {
  content: '\f213';
}

.genericon-tumblr:before {
  content: '\f214';
}

.genericon-instagram:before {
  content: '\f215';
}

.genericon-codepen:before {
  content: '\f216';
}

.genericon-polldaddy:before {
  content: '\f217';
}

.genericon-googleplus-alt:before {
  content: '\f218';
}

.genericon-path:before {
  content: '\f219';
}

.genericon-skype:before {
  content: '\f220';
}

.genericon-digg:before {
  content: '\f221';
}

.genericon-reddit:before {
  content: '\f222';
}

.genericon-stumbleupon:before {
  content: '\f223';
}

.genericon-pocket:before {
  content: '\f224';
}

.genericon-dropbox:before {
  content: '\f225';
}

/* Meta icons */
.genericon-comment:before {
  content: '\f300';
}

.genericon-category:before {
  content: '\f301';
}

.genericon-tag:before {
  content: '\f302';
}

.genericon-time:before {
  content: '\f303';
}

.genericon-user:before {
  content: '\f304';
}

.genericon-day:before {
  content: '\f305';
}

.genericon-week:before {
  content: '\f306';
}

.genericon-month:before {
  content: '\f307';
}

.genericon-pinned:before {
  content: '\f308';
}

/* Other icons */
.genericon-search:before {
  content: '\f400';
}

.genericon-unzoom:before {
  content: '\f401';
}

.genericon-zoom:before {
  content: '\f402';
}

.genericon-show:before {
  content: '\f403';
}

.genericon-hide:before {
  content: '\f404';
}

.genericon-close:before {
  content: '\f405';
}

.genericon-close-alt:before {
  content: '\f406';
}

.genericon-trash:before {
  content: '\f407';
}

.genericon-star:before {
  content: '\f408';
}

.genericon-home:before {
  content: '\f409';
}

.genericon-mail:before {
  content: '\f410';
}

.genericon-edit:before {
  content: '\f411';
}

.genericon-reply:before {
  content: '\f412';
}

.genericon-feed:before {
  content: '\f413';
}

.genericon-warning:before {
  content: '\f414';
}

.genericon-share:before {
  content: '\f415';
}

.genericon-attachment:before {
  content: '\f416';
}

.genericon-location:before {
  content: '\f417';
}

.genericon-checkmark:before {
  content: '\f418';
}

.genericon-menu:before {
  content: '\f419';
}

.genericon-refresh:before {
  content: '\f420';
}

.genericon-minimize:before {
  content: '\f421';
}

.genericon-maximize:before {
  content: '\f422';
}

.genericon-404:before {
  content: '\f423';
}

.genericon-spam:before {
  content: '\f424';
}

.genericon-summary:before {
  content: '\f425';
}

.genericon-cloud:before {
  content: '\f426';
}

.genericon-key:before {
  content: '\f427';
}

.genericon-dot:before {
  content: '\f428';
}

.genericon-next:before {
  content: '\f429';
}

.genericon-previous:before {
  content: '\f430';
}

.genericon-expand:before {
  content: '\f431';
}

.genericon-collapse:before {
  content: '\f432';
}

.genericon-dropdown:before {
  content: '\f433';
}

.genericon-dropdown-left:before {
  content: '\f434';
}

.genericon-top:before {
  content: '\f435';
}

.genericon-draggable:before {
  content: '\f436';
}

.genericon-phone:before {
  content: '\f437';
}

.genericon-send-to-phone:before {
  content: '\f438';
}

.genericon-plugin:before {
  content: '\f439';
}

.genericon-cloud-download:before {
  content: '\f440';
}

.genericon-cloud-upload:before {
  content: '\f441';
}

.genericon-external:before {
  content: '\f442';
}

.genericon-document:before {
  content: '\f443';
}

.genericon-book:before {
  content: '\f444';
}

.genericon-cog:before {
  content: '\f445';
}

.genericon-unapprove:before {
  content: '\f446';
}

.genericon-cart:before {
  content: '\f447';
}

.genericon-pause:before {
  content: '\f448';
}

.genericon-stop:before {
  content: '\f449';
}

.genericon-skip-back:before {
  content: '\f450';
}

.genericon-skip-ahead:before {
  content: '\f451';
}

.genericon-play:before {
  content: '\f452';
}

.genericon-tablet:before {
  content: '\f453';
}

.genericon-send-to-tablet:before {
  content: '\f454';
}

.genericon-info:before {
  content: '\f455';
}

.genericon-notice:before {
  content: '\f456';
}

.genericon-help:before {
  content: '\f457';
}

.genericon-fastforward:before {
  content: '\f458';
}

.genericon-rewind:before {
  content: '\f459';
}

.genericon-portfolio:before {
  content: '\f460';
}

.genericon-heart:before {
  content: '\f461';
}

.genericon-code:before {
  content: '\f462';
}

.genericon-subscribe:before {
  content: '\f463';
}

.genericon-unsubscribe:before {
  content: '\f464';
}

.genericon-subscribed:before {
  content: '\f465';
}

.genericon-reply-alt:before {
  content: '\f466';
}

.genericon-reply-single:before {
  content: '\f467';
}

.genericon-flag:before {
  content: '\f468';
}

.genericon-print:before {
  content: '\f469';
}

.genericon-lock:before {
  content: '\f470';
}

.genericon-bold:before {
  content: '\f471';
}

.genericon-italic:before {
  content: '\f472';
}

.genericon-picture:before {
  content: '\f473';
}

.genericon-fullscreen:before {
  content: '\f474';
}

/* Generic shapes */
.genericon-uparrow:before {
  content: '\f500';
}

.genericon-rightarrow:before {
  content: '\f501';
}

.genericon-downarrow:before {
  content: '\f502';
}

.genericon-leftarrow:before {
  content: '\f503';
}

/*--------------------------------------------------------------
3.1 - Links
--------------------------------------------------------------*/
a {
  color: #0d72b2;
  -webkit-transition: color .2s;
  transition: color .2s;
  text-decoration: none;
}
a:visited {
  color: #0d72b2;
}
a:hover, a:active {
  color: #0f92e5;
}
a:focus {
  outline: thin dotted;
}

/*--------------------------------------------------------------
3.2 - Horizontal Rules
--------------------------------------------------------------*/
hr {
  background-color: #eeeeee;
  border: 0;
  height: 1px;
  margin-bottom: 1.5em;
}

/*--------------------------------------------------------------
3.3 - Lists
--------------------------------------------------------------*/
ul,
ol {
  margin: 0 0 1.5em 3em;
}

ul {
  list-style: disc;
}

ol {
  list-style: decimal;
}

li > ul,
li > ol {
  margin-bottom: 0;
  margin-left: 1.5em;
}

dt {
  font-weight: 700;
}

dd {
  margin: 0 1.5em 1.5em;
}

/*--------------------------------------------------------------
3.4 - Tables
--------------------------------------------------------------*/
table {
  margin: 0 0 1.5em;
  width: 100%;
}

th {
  font-weight: 700;
}

@-webkit-keyframes grow {
  0% {
    -webkit-transform: scale(0.3);
    transform: scale(0.3);
  }

  60% {
    -webkit-transform: scale(1.15);
    transform: scale(1.15);
  }

  100% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
}

@keyframes grow {
  0% {
    -webkit-transform: scale(0.3);
    -ms-transform: scale(0.3);
    transform: scale(0.3);
  }

  60% {
    -webkit-transform: scale(1.15);
    -ms-transform: scale(1.15);
    transform: scale(1.15);
  }

  100% {
    -webkit-transform: scale(1);
    -ms-transform: scale(1);
    transform: scale(1);
  }
}
input[type="text"],
input[type="email"],
input[type="url"],
input[type="password"],
input[type="search"],
textarea {
  margin: 0;
  padding: 10px 12px;
  width: 100%;
  color: #555555;
  font-size: 15px;
  line-height: 1.4;
  border: 1px solid #d2dee6;
  background: #f4f8fa;
  -webkit-transition: all .15s ease-in-out;
  transition: all .15s ease-in-out;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
input[type="text"]::-webkit-input-placeholder,
input[type="email"]::-webkit-input-placeholder,
input[type="url"]::-webkit-input-placeholder,
input[type="password"]::-webkit-input-placeholder,
input[type="search"]::-webkit-input-placeholder,
textarea::-webkit-input-placeholder {
  color: #aaaaaa;
}
input[type="text"]:-moz-placeholder,
input[type="email"]:-moz-placeholder,
input[type="url"]:-moz-placeholder,
input[type="password"]:-moz-placeholder,
input[type="search"]:-moz-placeholder,
textarea:-moz-placeholder {
  color: #aaaaaa;
}
input[type="text"]::-moz-placeholder,
input[type="email"]::-moz-placeholder,
input[type="url"]::-moz-placeholder,
input[type="password"]::-moz-placeholder,
input[type="search"]::-moz-placeholder,
textarea::-moz-placeholder {
  color: #aaaaaa;
}
input[type="text"]:-ms-input-placeholder,
input[type="email"]:-ms-input-placeholder,
input[type="url"]:-ms-input-placeholder,
input[type="password"]:-ms-input-placeholder,
input[type="search"]:-ms-input-placeholder,
textarea:-ms-input-placeholder {
  color: #aaaaaa;
}
input[type="text"]::placeholder,
input[type="email"]::placeholder,
input[type="url"]::placeholder,
input[type="password"]::placeholder,
input[type="search"]::placeholder,
textarea::placeholder {
  color: #aaaaaa;
}
input[type="text"]:hover,
input[type="email"]:hover,
input[type="url"]:hover,
input[type="password"]:hover,
input[type="search"]:hover,
textarea:hover {
  border-color: #aaaaaa;
  background: white;
}
input[type="text"]:focus,
input[type="email"]:focus,
input[type="url"]:focus,
input[type="password"]:focus,
input[type="search"]:focus,
textarea:focus {
  color: #5c6671;
  border-color: #0085be;
  background: white;
  outline: none;
  -webkit-box-shadow: inset 0 1px 4px 0 rgba(0, 0, 0, 0.3);
  box-shadow: inset 0 1px 4px 0 rgba(0, 0, 0, 0.3);
}

textarea {
  overflow: auto;
  vertical-align: top;
  width: 100%;
  min-height: 150px;
}

input[type="checkbox"],
input[type="radio"] {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: inline-block;
  margin: -4px 4px 0 0;
  padding: 0;
  min-width: 16px;
  width: 16px;
  height: 16px;
  border: 1px solid #bbb;
  outline: 0;
  background: #fff;
  line-height: 0;
  text-align: center;
  vertical-align: middle;
  -webkit-appearance: none;
  clear: none;
  cursor: pointer;
}
input[type="checkbox"]:disabled,
input[type="radio"]:disabled {
  opacity: 0.7;
}
input[type="checkbox"]:checked:before,
input[type="radio"]:checked:before {
  float: left;
  display: inline-block;
  vertical-align: middle;
  width: 16px;
  font: 400 23px/1 Noticons;
  speak: none;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  color: #0085be;
  -webkit-animation: grow .2s ease-in-out;
  animation: grow .2s ease-in-out;
}

input[type=radio] {
  border-radius: 50%;
  margin-right: 4px;
  line-height: 10px;
}
input[type=radio]:checked:before {
  float: left;
  display: inline-block;
  content: '\2022';
  margin: 3px;
  width: 8px;
  height: 8px;
  text-indent: -9999px;
  background: #0085be;
  vertical-align: middle;
  border-radius: 50%;
  -webkit-animation: grow .2s ease-in-out;
  animation: grow .2s ease-in-out;
}

input[type=checkbox]:checked:before {
  content: '\f418';
  margin: -4px 0 0 -5px;
}

button,
input,
select,
textarea {
  font-size: 100%;
  margin: 0;
  vertical-align: baseline;
  *vertical-align: middle;
}

input[type="search"] {
  -webkit-appearance: textfield;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}

input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none;
}

button::-moz-focus-inner,
input::-moz-focus-inner {
  border: 0;
  padding: 0;
}

.button--primary, .button--secondary,
button,
input[type="submit"], .button--jetpack {
  display: inline-block;
  overflow: hidden;
  border-radius: 3px;
  font-size: 13px;
  line-height: 2;
  margin: 0;
  padding: .4em .9em;
  text-overflow: ellipsis;
  text-decoration: none;
  white-space: nowrap;
  outline: 0;
  vertical-align: top;
  cursor: pointer;
  -webkit-appearance: none;
}
.hidden.button--primary, .hidden.button--secondary,
button.hidden,
input.hidden[type="submit"], .hidden.button--jetpack {
  display: none;
}
[disabled].button--primary, [disabled].button--secondary,
button[disabled],
input[disabled][type="submit"], [disabled].button--jetpack, .button--primary:disabled, .button--secondary:disabled,
button:disabled,
input[type="submit"]:disabled, .button--jetpack:disabled {
  cursor: default;
}

.button--primary {
  background: #00aadc;
  color: white;
}
.button--primary:active, .button--primary:hover, .button--primary:focus {
  color: white;
  background: #33bbe3;
}
.button--primary:visited {
  color: white;
}
[disabled].button--primary, .button--primary:disabled {
  background: #298cba;
  border-color: #1b607f;
  color: #94cde7;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.1);
}

.button--secondary,
button,
input[type="submit"] {
  background: #e2edf2;
  color: #6f7a88;
}
.button--secondary:active,
button:active,
input[type="submit"]:active, .button--secondary:hover,
button:hover,
input[type="submit"]:hover, .button--secondary:focus,
button:focus,
input[type="submit"]:focus {
  color: #324155;
}
.button--secondary:visited,
button:visited,
input[type="submit"]:visited {
  color: #6f7a88;
}
[disabled].button--secondary,
button[disabled],
input[disabled][type="submit"], .button--secondary:disabled,
button:disabled,
input[type="submit"]:disabled {
  color: #aaa;
  border-color: #ddd;
  text-shadow: 0 1px 0 #fff;
}

.button--jetpack {
  color: #fff;
  background: #518d2a;
  -webkit-box-shadow: 0 6px 0 #3e6c20, 0 6px 3px rgba(0, 0, 0, 0.4);
  box-shadow: 0 6px 0 #3e6c20, 0 6px 3px rgba(0, 0, 0, 0.4);
}

.button--large {
  height: 36px;
  line-height: 36px;
  padding: 0 16px 2px;
}

.button--hero {
  font-size: 15px;
  font-weight: 600;
  height: 46px;
  line-height: 44px;
  padding: 0 23px;
}

input[type=reset], input[type=reset]:hover, input[type=reset]:active, input[type=reset]:focus {
  background: 0 0;
  border: 0;
  padding: 0 2px 1px;
  width: auto;
}

p .button {
  vertical-align: baseline;
}

button::-moz-focus-inner,
input[type=reset]::-moz-focus-inner,
input[type=button]::-moz-focus-inner,
input[type=submit]::-moz-focus-inner {
  padding: 0;
}

.clear:before, .clear:after {
  content: "";
  display: table;
}
.clear:after {
  clear: both;
}

.jetpack-hero {
  position: relative;
  overflow: hidden;
  margin: 0 auto 80px;
  background: #81a844;
  background-image: -webkit-gradient(linear, left top, left bottom, from(#81a844), to(#8eb74e));
  background-image: -webkit-linear-gradient(top, #81a844, #8eb74e);
  background-image: linear-gradient(top, #81a844, #8eb74e);
  text-align: center;
}
.jetpack-hero .button--primary {
  margin-bottom: 8px;
  font-size: 16px;
}
.jetpack-hero .step-description {
  max-width: 650px;
  margin: 7px auto 50px;
}

.jetpack-hero__title {
  position: relative;
  margin-top: 60px;
  color: #fff;
  text-shadow: rgba(0, 0, 0, 0.11765) 0px 1px 1px;
  z-index: 2;
}
@media (max-width: 500px) {
  .jetpack-hero__title {
    font-size: 30px;
  }
}

.jetpack-hero__info {
  position: relative;
  margin-top: 110px;
  padding: 60px 30px 30px;
  background: #f9f9f9;
  z-index: 4;
}
.jetpack-hero__info:before {
  content: "";
  position: absolute;
  bottom: 100%;
  left: 0;
  width: 100%;
  height: 93px;
  margin-bottom: -1px;
  background: url(../img/the-cloud.svg) center bottom repeat-x;
  z-index: 4;
}

@media (max-width: 768px) {
  .flyby {
    display: none;
  }
}

.flyer {
  position: absolute;
  top: 220px;
  left: 16%;
  z-index: 3;
  -webkit-animation: flyer 3.4s 2s ease-in-out;
  animation: flyer 3.4s 2s ease-in-out;
}
.flyer:nth-child(2) {
  left: 40%;
  width: 120px;
  height: 131px;
  -webkit-animation-delay: 4.6s;
  animation-delay: 4.6s;
  -webkit-animation-duration: 2.4s;
  animation-duration: 2.4s;
}
.flyer:nth-child(3) {
  left: 30%;
  width: 60px;
  height: 66px;
  -webkit-animation-delay: 5.8s;
  animation-delay: 5.8s;
  -webkit-animation-duration: 4.5s;
  animation-duration: 4.5s;
  z-index: 0;
}

@-webkit-keyframes "flyer" {
  0% {
    -webkit-transform: translate3d(0px, 0px, 0px);
    transform: translate3d(0px, 0px, 0px);
  }

  100% {
    -webkit-transform: translate3d(570px, -570px, 0px);
    transform: translate3d(570px, -570px, 0px);
  }
}

@keyframes "flyer" {
  0% {
    -webkit-transform: translate3d(0px, 0px, 0px);
    -ms-transform: translate3d(0px, 0px, 0px);
    transform: translate3d(0px, 0px, 0px);
  }

  100% {
    -webkit-transform: translate3d(570px, -570px, 0px);
    -ms-transform: translate3d(570px, -570px, 0px);
    transform: translate3d(570px, -570px, 0px);
  }
}
.themes-box {
  max-width: 960px;
  margin: 0 auto;
  border: 6px solid #e8f0f5;
  overflow: hidden;
}

.theme {
  float: left;
  padding-top: 22%;
  width: 50%;
  background: #fff;
  border: 6px solid #e8f0f5;
  -webkit-transition: -webkit-box-shadow .2s ease-in-out;
  transition: box-shadow .2s ease-in-out;
  cursor: pointer;
}
.theme:nth-child(4n-2), .theme:nth-child(4n-1) {
  background: #ccc;
}
.theme:hover {
  -webkit-box-shadow: inset 0 0 0 4px #00aadc;
  box-shadow: inset 0 0 0 4px #00aadc;
}
@media (max-width: 500px) {
  .theme {
    float: none;
    padding-top: 46%;
    width: 100%;
  }
}

.theme-buttons {
  margin: 0 13px 13px 0;
  text-align: right;
}
.theme-buttons .button--large {
  -webkit-box-shadow: 0 2px 3px rgba(0, 0, 0, 0.2);
  box-shadow: 0 2px 3px rgba(0, 0, 0, 0.2);
}
.theme-buttons .small-icon {
  font-size: 15px;
  margin: 0 8px 0 -3px;
}
.theme-buttons .fa-external-link {
  position: relative;
  top: 1px;
}

.first-post {
  margin: 0 auto;
  max-width: 700px;
}

#title-prompt-text,
#mce_48-body,
.wp-editor-tabs {
  display: none;
}

#title {
  margin-bottom: 20px;
  border-radius: 3px;
  background: #fff;
  border: 1px solid #ddd;
  color: #222;
  font-size: 28px;
  font-weight: 700;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.1);
}
@media (max-width: 768px) {
  #title {
    font-size: 18px;
  }
}

#mce_41-body,
#postdivrich {
  border: 1px solid #ddd;
  border-radius: 3px;
}

#mce_41 {
  background: #f9f9f9;
}

.skip-post {
  display: inline-block;
  margin-top: 13px;
  margin-left: 10px;
}

.mceContentBody {
  margin: 0 auto;
}

.connect-social {
  position: relative;
  max-width: 700px;
  margin: 0 auto;
  padding: 30px;
  background: #eee;
}
.connect-social:before {
  position: absolute;
  content: '';
  width: 0;
  height: 0;
  bottom: 100%;
  border-left: 20px solid transparent;
  border-right: 20px solid transparent;
  border-bottom: 20px solid #eeeeee;
  left: 50%;
  margin-left: -20px;
}
.connect-social + .skip {
  margin: 15px auto 60px;
}

.connections {
  overflow: hidden;
}

.connect-social__link {
  float: left;
  display: block;
  margin: 0 2%;
  padding: 13px 18px;
  width: 46%;
  border-radius: 3px;
  color: #fff;
  font-size: 18px;
  text-align: center;
  background: #0085be;
}
.connect-social__link:hover, .connect-social__link:active, .connect-social__link:visited {
  color: #fff;
}
.connect-social__link.fb {
  background: #485ea0;
}
.connect-social__link.tw {
  background: #51a4e4;
}
.connect-social__link.connected {
  background: #73c650;
}
.connect-social__link .fa {
  float: left;
  position: relative;
  top: 1px;
  font-size: 23px;
}
@media (max-width: 768px) {
  .connect-social__link {
    float: none;
    margin: 0 0 10px;
    width: auto;
  }
}

.social-assurance {
  clear: both;
  margin: 21px auto 0;
  padding: 4px;
  max-width: 440px;
  color: #666;
  font-size: 14px;
  text-align: center;
}
.social-assurance strong {
  color: #000;
}

body {
  background: #f9f9f9;
}

header {
  background: #222;
  height: 33px;
  left: 0;
  right: 0;
  overflow: hidden;
  position: fixed;
  top: 0;
  z-index: 5;
}
header .genericon {
  color: #999;
  font-size: 24px;
  height: 24px;
  margin: 4px 0 0 6px;
  width: 24px;
}
header .progress {
  color: #bbb;
  position: absolute;
  top: 0;
  right: 6px;
}
header .progress li {
  background: #555;
  display: inline-block;
  height: 12px;
  list-style: none;
  margin: 10px 4px 0 0;
  width: 12px;
  border-radius: 1px;
}
header .progress li.done {
  background: #93d07b;
}
header .progress span {
  float: left;
  margin: 6px 12px 0 0;
}
header .progress ul {
  float: left;
  margin: 0;
  padding: 0;
}

.step {
  margin: 33px 0 0;
}
.step h1 {
  font: 300 2.5em/1.4 'Open Sans', Helvetica, sans-serif;
}
@media (max-width: 500px) {
  .step h1 {
    font-size: 1.875em;
  }
}

.container {
  overflow: hidden;
}

.section-header {
  margin: 0 auto;
  padding: 3% 30px;
  max-width: 650px;
  text-align: center;
}

.skip {
  color: #999;
  text-align: center;
}
.skip a {
  color: #999;
  text-decoration: underline;
}
.skip a:hover {
  text-decoration: none;
}

.step-description {
  color: #666;
  margin: -13px 0 1.83333em;
  padding: 0;
  font-size: 1.125em;
  line-height: 1.6;
}
@media (max-width: 500px) {
  .step-description {
    font-size: 1em;
  }
}

.med-icon {
  float: left;
  font-size: 23px;
  margin: 11px 9px 0 0;
}

.step1 section.step-1, .step2 section.step-2, .step3 section.step-3, .step4 section.step-4 {
  display: block;
}

.options-box {
  background: #eee;
  margin-bottom: 33px;
  overflow: hidden;
  padding: 2%;
}
.options-box .option {
  background: #fff;
  border: 4px solid #e8e8e8;
  color: #999;
  float: left;
  font-size: 18px;
  margin: 1.5%;
  padding: 23px;
  position: relative;
  text-align: center;
  width: 30%;
  border-radius: 3px;
  -webkit-transition: all .2s ease-in-out;
  transition: all .2s ease-in-out;
  z-index: 1;
}
.options-box .option:hover, .options-box .option.active {
  background: #eef5fb;
  border: 4px solid #00aadc;
  color: #333;
}
.options-box .option span.big-icon {
  display: block;
  font-size: 43px;
  margin-bottom: 13px;
}
.options-box .social-link {
  float: left;
  font-size: 18px;
  margin: 1.6% 2%;
  padding: 13px 18px;
  position: relative;
  text-align: center;
  width: 46%;
  border-radius: 3px;
  z-index: 1;
}
.options-box .social-link.fb {
  background: #485ea0;
}
.options-box .social-link.tw {
  background: #51a4e4;
}
.options-box .social-link.connected {
  background: #73c650 !important;
}
.options-box .social-link .bg {
  background: #fff;
}
.options-box .social-link .fa {
  color: #fff;
  float: left;
  font-size: 23px;
  margin: 2px 8px 0 0;
}
.options-box .social-link .title {
  color: #fff;
}
.options-box .social-link .wrap {
  display: block;
  position: relative;
}
.options-box .social-assurance {
  clear: both;
  color: #666;
  padding: 4px;
  text-align: center;
}
.options-box .social-assurance strong {
  color: #000;
}

@media (max-width: 990px) {
  section .container .options-box .option {
    font-size: 16px;
    white-space: nowrap;
  }
}
@media (max-width: 768px) {
  section .container .options-box .option {
    width: 46%;
  }
}
@media (max-width: 530px) {
  section .container .options-box .option {
    width: 95%;
  }
}
.jetpack-login {
  background: #f6f6f6;
  border: 1px solid #eee;
  margin-bottom: 33px;
  padding: 23px 0;
  text-align: center;
}
.jetpack-login a {
  color: #999;
  text-decoration: underline;
}
.jetpack-login a:hover {
  text-decoration: none;
}

.jetpack-signup {
  background: #eee;
}
.jetpack-signup input[type="text"] {
  background: #fff;
  border-color: #ddd;
  margin: 6px 0 23px;
}
.jetpack-signup label {
  font-weight: bold;
}

.login .signing-up {
  display: none;
}
.login .logging-in {
  display: inline-block;
}

.signup .signing-up {
  display: inline-block;
}
.signup .logging-in {
  display: none;
}

/*# sourceMappingURL=jetpack-start.css.map */
