// ==========================================================================
// Colors
// ==========================================================================

// Blues
$wordpress-blue: #0085be;
$light-blue: #78dcfa;
$medium-blue: #00aadc;
$dark-blue: #005082;

// Primary Grays
$ultra-light-gray: #f4f8fA;
$light-gray: #e8f0f5;
$medium-gray: #d2dee6;
$dark-gray: #324155;

// Secondary Grays
$white: #fff;
$groups-bg: lighten($light-blue, 30%);
// $text-gray: tint($dark-gray, 50%);

// Oranges
$fire-orange: #f0821e;
$jazzy-orange: #d54e21;

// Alerts
$alert-yellow: #ffba00;
$alert-red: #dd3d36;
$alert-green: #4cb420;

// Link hovers
$link-highlight: #33bbe3;


// Jetpack colors
$jetpack-green: #81a844;
$jetpack-cloud: #f9f9f9;
