/*
Theme Name: Twenty Eleven

Adding support for language written in a Right To Left (RTL) direction is easy -
it's just a matter of overwriting all the horizontal positioning attributes
of your CSS stylesheet in a separate stylesheet file named rtl.css.

http://codex.wordpress.org/Right_to_Left_Language_Support

*/

/* =Reset reset
----------------------------------------------- */

caption, th, td {
	text-align: right;
}

/* =Structure
----------------------------------------------- */

body {
	direction:rtl;
	unicode-bidi:embed;
}

/* Showcase */
.page-template-showcase-php section.recent-posts {
	float: left;
	margin: 0 31% 0 0;
}
.page-template-showcase-php #main .widget-area {
	float: right;
	margin: 0 0 0 -22.15%;
}

/* One column */

.one-column article.feature-image.small .entry-summary a {
	left: auto;
	right: -9%;
}

/* Simplify the pullquotes and pull styles */
.one-column.singular .entry-meta .edit-link a {
	right: 0px;
	left: auto;
}
/* Make sure we have room for our comment avatars */
.one-column .commentlist > li.comment {
	margin-left: 0;
	margin-right: 102px;
}
/* Make sure the logo and search form don't collide */
.one-column #branding #searchform {
	right: auto;
	left: 40px;
}
/* Talking avatars take up too much room at this size */
.one-column .commentlist > li.comment {
	margin-right: 0;
}
.one-column .commentlist > li.comment .comment-meta,
.one-column .commentlist > li.comment .comment-content {
	margin-right: 0;
	margin-left: 85px;
}
.one-column .commentlist .avatar {
	right: auto;
	left: 1.625em;
}
.one-column .commentlist .children .avatar {
	left: auto;
	right: 2.2em;
}

/* =Global
----------------------------------------------- */

/* Text elements */
p {
	margin-bottom: 1.625em;
}
ul, ol {
	margin: 0 2.5em 1.625em 0;
}
.ltr ul, ol {
	margin: 0 0 1.625em  2.5em;
}
blockquote {
	font-family: Arial, sans-serif;
}
blockquote em, blockquote i, blockquote cite {
	font-style: normal;
}

/* Forms */
textarea {
	padding-left: 0;
	padding-right: 3px;
}
input#s {
	background-position: 97% 6px;
	padding: 4px 28px 4px 10px;
}

/* Assistive text */
#access a.assistive-text:active,
#access a.assistive-text:focus {
	left: auto;
	right: 7.6%;
}

/* =Header
----------------------------------------------- */

#site-title {
	margin-right: 0;
	margin-left: 270px;
}

#site-description {
	margin: 0 0 3.65625em 270px;
}

/* =Menu
-------------------------------------------------------------- */

#access {
	float: right;
}
#access ul {
	margin: 0 -0.8125em 0 0;
	padding-right: 0;
}
#access li {
	float: right;
}
#access ul ul {
	float: right;
	left: auto;
	right: 0;
}
#access ul ul ul {
	left: auto;
	right: 100%;
}

/* Search Form */
#branding #searchform {
	right: auto;
	left: 7.6%;
	text-align: left;
}
#branding #s {
	float: left;
}
#branding .only-search + #access div {
	padding-right: 0;
	padding-left: 205px;
}


/* =Content
----------------------------------------------- */
.entry-title,
.entry-header .entry-meta {
	padding-right: 0;
	padding-left: 76px;
}
.entry-content td,
.comment-content td {
	padding: 6px 0 6px 10px;
}
.page-link span {
	margin-right: 0;
	margin-left: 6px;
}
.entry-meta .edit-link a {
	float: left;
}
/* Images */

.wp-caption .wp-caption-text,
.gallery-caption {
	font-family: Arial, sans-serif;
}
.wp-caption .wp-caption-text {
	padding: 10px 40px 5px 0px;
}
.wp-caption .wp-caption-text:before {
	margin-right: 0;
	margin-left: 5px;
	left: auto;
	right: 10px;
}
#content .gallery-columns-4 .gallery-item {
	padding-right:0;
	padding-left:2%;
}

/* Author Info */
.singular #author-info {
	margin: 2.2em -35.4% 0 -35.6%;
}
#author-avatar {
	float: right;
	margin-right: 0;
	margin-left: -78px;
}
#author-description {
	float: right;
	margin-left: 0;
	margin-right: 108px;
}
/* Comments link */
.entry-header .comments-link a {
	background-image: url(images/comment-bubble-rtl.png);
	right: auto;
	left: 0;
}

/*
	Post Formats Headings
*/
.singular .entry-title,
.singular .entry-header .entry-meta {
	padding-left: 0;
}
.singular .entry-header .entry-meta {
	left: auto;
	right: 0;
}
.singular .entry-meta .edit-link a {
	left: auto;
	right: 50px;
}


/* =Gallery
----------------------------------------------- */

.format-gallery .gallery-thumb {
	float: right;
	margin: .375em 0 0 1.625em;
}


/* =Status
----------------------------------------------- */

.format-status img.avatar {
	float: right;
	margin: 4px 0 2px 10px;
}


/* =Image
----------------------------------------------- */

.indexed.format-image div.entry-meta {
	float: right;
}
/* =error404
----------------------
------------------------- */
.error404 #main .widget {
	float: right;
	margin-right: auto;
	margin-left: 3.7%;
}
.error404 #main .widget_archive {
	margin-left: 0;
}
.error404 #main .widget_tag_cloud {
	margin-left: 0;
}

/* =Showcase
----------------------------------------------- */

article.intro .edit-link a {
	right: auto;
	left: 20px;
}

/* Featured post */
section.featured-post {
	float: right;
}

/* Small featured post */
section.featured-post .attachment-small-feature {
	float: left;
	margin: 0 0 1.625em -8.9%;
	right: auto;
	left: -15px;
}
article.feature-image.small {
	float: right;
}
article.feature-image.small .entry-summary p a {
	left:auto;
	right: -23.8%;
	padding: 9px 85px 9px 26px;
}

/* Large featured post */
section.feature-image.large .hentry {
	left:auto;
	right: 9%;
	margin: 1.625em 0 0 9%;
}
/* Featured Slider */
.featured-posts .showcase-heading {
	padding-left: 0;
	padding-right: 8.9%;
}
.featured-posts section.featured-post {
	left: auto;
	right: 0;
}
#content .feature-slider {
	right: auto;
	left: 8.9%;
}
.feature-slider li {
	float: right;
}
/* Recent Posts */
section.recent-posts .other-recent-posts a[rel="bookmark"] {
	float: right;
}
section.recent-posts .other-recent-posts .comments-link a,
section.recent-posts .other-recent-posts .comments-link > span {
	padding: 0.3125em 1em 0.3125em 0;
	left: 0;
	text-align: left;
}

/* =Attachments
----------------------------------------------- */

/* =Navigation
-------------------------------------------------------------- */

.nav-previous {
	float: right;
}
.nav-next {
	float: left;
	text-align: left;
}

/* Singular navigation */
#nav-single {
	float: left;
	text-align: left;
}
#nav-single .nav-next {
	padding-left: 0;
	padding-right: .5em;
}


/* =Widgets
----------------------------------------------- */

.widget ul ul {
	margin-left: 0;
	margin-right: 1.5em;
}

/* Twitter */
.widget_twitter .timesince {
	margin-right: 0;
	margin-left: -10px;
	text-align: left;
}

/* =Comments
----------------------------------------------- */

.commentlist .children li.comment {
	border-left: none;
	border-right: 1px solid #ddd;
	-moz-border-radius: 3px 0  0 3px;
	border-radius: 3px 0 0 3px;
}
.commentlist .children li.comment .comment-meta {
	margin-left: 0;
	margin-right: 50px;
}
.commentlist .avatar {
	left: auto;
	right: -102px;
}
.commentlist > li:before {
	content: url(images/comment-arrow-rtl.png);
	left:auto;
	right: -21px;
}
.commentlist > li.pingback:before {
	content: '';
}
.commentlist .children .avatar {
	left: auto;
	right: 2.2em;
}

/* Post author highlighting */
.commentlist > li.bypostauthor:before {
	content: url(images/comment-arrow-bypostauthor-rtl.png);
}

/* sidebar-page.php comments */
/* Make sure we have room for our comment avatars */
.page-template-sidebar-page-php .commentlist > li.comment,
.page-template-sidebar-page-php.commentlist .pingback {
	margin-left: 0;
	margin-right: 102px;
}

/* Comment Form */
#respond .comment-form-author label,
#respond .comment-form-email label,
#respond .comment-form-url label,
#respond .comment-form-comment label {
	left: auto;
	right: 4px;
}
#respond .comment-form-author label,
#respond .comment-form-email label,
#respond .comment-form-url label,
#respond .comment-form-comment label {
	-webkit-box-shadow: -1px 2px 2px rgba(204,204,204,0.8);
	-moz-box-shadow: -1px 2px 2px rgba(204,204,204,0.8);
	box-shadow: -1px 2px 2px rgba(204,204,204,0.8);
}
#respond .comment-form-author .required,
#respond .comment-form-email .required {
	left: auto;
	right: 75%;
}
#respond .form-submit {
	float: left;
}
#respond input#submit {
	left: auto;
	right: 30px;
	padding: 5px 22px 5px 42px;
}
#respond #cancel-comment-reply-link {
	margin-left: 0;
	margin-right: 10px;
}
#cancel-comment-reply-link {
	right: auto;
	left: 1.625em;
}

/* =Footer
----------------------------------------------- */

/* Two Footer Widget Areas */
#supplementary.two .widget-area {
	float: right;
	margin-right: 0;
	margin-left: 3.7%;
}
#supplementary.two .widget-area + .widget-area {
	margin-left: 0;
}

/* Three Footer Widget Areas */
#supplementary.three .widget-area {
	float: right;
	margin-right: 0;
	margin-left: 3.7%;
}
#supplementary.three .widget-area + .widget-area + .widget-area {
	margin-left: 0;
}

/* Site Generator Line */
#site-generator .sep {
	background-position: right center;
}


/* =Responsive Structure
----------------------------------------------- */

@media (max-width: 800px) {
	/* Simplify the showcase template when small feature */
	section.featured-post .attachment-small-feature,
	.one-column section.featured-post .attachment-small-feature {
		float: right;
	}
	article.feature-image.small {
		float: left;
	}
	article.feature-image.small .entry-summary p a {
		right: 0;
	}
	.singular .entry-meta .edit-link a {
		left: auto;
		right: 0px;
	}
	/* Make sure we have room for our comment avatars */
	.commentlist > li.comment,
	.commentlist .pingback {
		margin-left: 0;
		margin-right: 102px;
	}
	/* No need to float footer widgets at this size */
	#colophon #supplementary .widget-area {
		margin-left: 0;
	}
	/* No need to float 404 widgets at this size */
	.error404 #main .widget {
		margin-left: 0;
	}
}
@media (max-width: 650px) {
	/* @media (max-width: 650px) Reduce font-sizes for better readability on smaller devices */
	#site-title,
	#site-description {
		margin-left: 0;
	}
	/* Talking avatars take up too much room at this size */
	.commentlist > li.comment,
	.commentlist > li.pingback {
		margin-right: 0 !important;
	}
	.commentlist .children .avatar {
		left: auto;
		right: 2.2em;
	}
	/* Use the available space in the smaller comment form */
	#respond .comment-form-author .required,
	#respond .comment-form-email .required {
	    left: auto;
	    right: 95%;
	}
	#content .gallery-columns-3 .gallery-item {
		padding-right: 0;
		padding-left:2%;
	}
}
@media (max-width: 450px) {
	#content .gallery-columns-2 .gallery-item {
		padding-right:0;
		padding-left:4%;
	}
}

/* =Print
----------------------------------------------- */

@media print {
	#primary {
	    float: right;
	}
	/* Comments */
	.commentlist .avatar {
	    left: auto;
	    right: 2.2em;
	}
	.commentlist li.comment .comment-meta {
	    margin-left: 0;
	    margin-right: 50px;
	}
}

/* =IE7
----------------------------------------------- */

#ie7 section.recent-posts {
	margin-right: 0;
	margin-left: 7.6%;
}
