img.mojo-thumbnail:hover {
	/* IE 8 */
	-ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
	/* IE 5-7 */
	filter: alpha(opacity=80);
	/* Netscape */
	-moz-opacity: 0.8;
	/* Safari 1.x */
	-khtml-opacity: 0.8;
	/* Good browsers */
	opacity: 0.8;
}
input.mm-btn-primary{
	padding: 2px 10px;
	line-height: 24px;
	font-size:16px;
}
.mm-btn-primary{
	-moz-user-select: none;
	background-color: #EEEEEE;
	background-image: none;
	border: 0 none;
	border-radius: 3px;
	box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.15);
	cursor: pointer;
	display: inline-block;
	font-size: 16px;
	padding: 6px 8px;
	line-height: 16px;
	text-align: center;
	text-decoration: none;
	transform: translateZ(0px);
	transition: background-color 300ms ease-in-out 0s;
	vertical-align: middle;
	white-space: nowrap;
	background-color: #92C933;
	color: #fff;
}
.mm-btn-primary:hover{
	background-color: #74A029;
}
#mojo-sg-form{
	position: relative;
	top: 66px;
}
#mojo-sg-form p{
	line-height: 2.8rem;
	padding-left: 25px;
}
#mojo-sg-form .mm-btn-primary{
	display: block;
	margin: 0 auto;
	font-size: 16px;
	font-weight: bold;
	line-height: 20px;
	padding: 14px 30px;
}
#TB_title{
	background-color: #3B3F41 !important;
}
#mojo-sg-form label{
	width: 200px;
	display: inline-block;
	margin: 10px 0;
	font-size: 14px;
}
#mojo-sg-form select{
	width: 160px;
	display: inline-block;
}
#mojo-sg-form input[type="submit"] {
	cursor: pointer;
}
.mm_sg_header{
	background-color: #3B3F41;
	left: 0;
	position: absolute;
	top: 27px;
	width: 670px;
	padding-bottom: 10px;
}
.mm_sg_header img{
	display: block;
	margin: 0 auto;
}
.toplevel_page_mojo-themes .theme-browser .theme{
	background: none repeat scroll 0 0 #fff;
}

.toplevel_page_mojo-themes .theme-browser .theme .theme-screenshot:after{
	padding-top: 60%;
}

.toplevel_page_mojo-themes .theme-browser .theme .mojo-theme-actions{
	opacity: 1;
}

.toplevel_page_mojo-themes .theme-browser .theme .mojo-theme-actions form{
	display: inline-block;
}

.toplevel_page_mojo-themes .theme-browser .theme .mojo-theme-actions .price{
	display: inline-block;
	font-size: 1rem;
}

.wp-full-overlay-sidebar{
	box-shadow: 0px 0px 10px 0px #000;
}

.admin_page_mojo-theme-preview .theme-details .theme-version,
.admin_page_mojo-theme-preview .theme-details .theme-updated,
.admin_page_mojo-theme-preview .theme-details .theme-sales {
	margin: 15px 0;
	display: block;
	text-align: left;
	float: none;
}


/*Styles from theme_large test */

.toplevel_page_mojo-themes .theme-browser .theme{ 
	margin: 1%; 
	width: 49%;
}
.toplevel_page_mojo-themes .theme-browser .theme:nth-of-type(odd){ 
	margin: 0 1% 2% 0; 
	width: 49%;
}
.toplevel_page_mojo-themes .theme-browser .theme:nth-of-type(even){ 
	margin: 0 0 2% 1%; 
	width: 49%;
}
.toplevel_page_mojo-themes .theme-browser h3.theme-name{
	box-shadow: 0 0 0;
	display: inline-block;
	max-width: 45%;
}
.toplevel_page_mojo-themes .theme-browser .mojo-theme-actions{
	display: inline-block;
	position: absolute;
	right: 15px;
	bottom: 10px;
}
.toplevel_page_mojo-themes .theme-browser .mojo-theme-actions .price{
	position: relative;
	padding: 5px;
}
.toplevel_page_mojo-themes .theme-browser .mojo-theme-actions .mm-btn-primary,
.toplevel_page_mojo-themes .theme-browser .mojo-theme-actions .button-secondary{
	margin: 5px 10px;
}
@media screen and (max-width: 640px) {
	.toplevel_page_mojo-themes .theme-browser .theme,
	.toplevel_page_mojo-themes .theme-browser .theme:nth-of-type(odd),
	.toplevel_page_mojo-themes .theme-browser .theme:nth-of-type(even) {
		margin: 1% 0; 
		width: 100%;
	}
}
@media screen and (max-width: 1200px) {
	.toplevel_page_mojo-themes .theme-browser h3.theme-name {
		visibility: hidden;
	}
}
/* End of themes_large */


/*MOJO Services*/

.marketplace_page_mojo-services .service-browser .service {
	border: 1px solid #dedede;
	box-shadow: 0 1px 1px -1px rgba(0, 0, 0, 0.1);
	box-sizing: border-box;
	cursor: pointer;
	float: left;
	margin: 0 4% 4% 0;
	position: relative;
	width: 30.6%;
}
.marketplace_page_mojo-services .service-browser .service .service-screenshot img {
	height: auto;
	transition: opacity 0.2s ease-in-out 0s;
	width: 100%;

}
.marketplace_page_mojo-services .service-browser .service .service-screenshot:after {
	display: block;
}
.marketplace_page_mojo-services .service-browser .service{
	background: none repeat scroll 0 0 #fff;
}

.marketplace_page_mojo-services .service-browser .service .service-screenshot:after{
	padding-top: 60%;
}

.marketplace_page_mojo-services .service-browser .service .mojo-service-actions{
	opacity: 1;
}

.marketplace_page_mojo-services .service-browser .service .mojo-service-actions form{
	display: inline-block;
}

.marketplace_page_mojo-services .service-browser .service .mojo-service-actions .price{
	display: inline-block;
	font-size: 1rem;
}

.marketplace_page_mojo-services .service-browser{
	margin-top: 25px;
}

.marketplace_page_mojo-services .service-browser .service{ 
	margin: 1%; 
	width: 49%;
}
.marketplace_page_mojo-services .service-browser .service:nth-of-type(odd){ 
	margin: 0 1% 2% 0; 
	width: 49%;
}
.marketplace_page_mojo-services .service-browser .service:nth-of-type(even){ 
	margin: 0 0 2% 1%; 
	width: 49%;
}
.marketplace_page_mojo-services .service-browser h3.service-name{
	box-shadow: 0 0 0;
	display: inline-block;
	max-width: 45%;
	background: none repeat scroll 0 0 rgba(255, 255, 255, 0.65);
	font-size: 15px;
	font-weight: 600;
	height: 18px;
	margin: 0;
	overflow: hidden;
	padding: 15px;
	text-overflow: ellipsis;
	white-space: nowrap;
}
.marketplace_page_mojo-services .service-browser .mojo-service-actions{
	display: inline-block;
	position: absolute;
	right: 15px;
	bottom: 10px;
}
.marketplace_page_mojo-services .service-browser .mojo-service-actions .price{
	position: relative;
	padding: 5px;
}
.marketplace_page_mojo-services .service-browser .mojo-service-actions .mm-btn-primary,
.marketplace_page_mojo-services .service-browser .mojo-service-actions .button-secondary{
	margin: 5px 10px;
}
@media screen and (max-width: 640px) {
	.marketplace_page_mojo-services .service-browser .service,
	.marketplace_page_mojo-services .service-browser .service:nth-of-type(odd),
	.marketplace_page_mojo-services .service-browser .service:nth-of-type(even) {
		margin: 1% 0; 
		width: 100%;
	}
}
@media screen and (max-width: 1200px) {
	.marketplace_page_mojo-services .service-browser h3.service-name {
		visibility: hidden;
	}
}
/*End MOJO Services*/

div.mojo-notice{
	position: relative;
	margin-right: 20px;
	margin-top: 40px;
}
div.mojo-notice .mojo-dismiss{
	padding: 5px;
	position: absolute;
	right: 0;
	top: 0;
	color: #92c933;
}